@@ -1,5 +1,5 @@
-## ----include=FALSE-------------------------------------------------------
-require(knitr)
+## ----include = FALSE-----------------------------------------------------
+library(knitr)
 opts_chunk$set(echo = TRUE, eval = FALSE)
 
 ## ----the-code------------------------------------------------------------
